@@ -9,8 +9,11 @@
 #'
 rangeDS <- function(xvect) {
   # back-up current .Random.seed and revert on.exit
-  old_seed <- .Random.seed
-  on.exit(.Random.seed <- old_seed, add = TRUE)
+  if (exists(x = ".Random.seed", envir = globalenv())) {
+      assign(x = ".old_seed", value = .Random.seed, envir = parent.frame());
+      on.exit({ assign(x = ".Random.seed", value = parent.frame()$.old_seed, envir = globalenv()); remove(".old_seed", envir = parent.frame()) }, add = TRUE)
+  } else
+      on.exit(if (exists(x = ".Random.seed", envir = globalenv())) remove(".Random.seed", envir = globalenv()), add = TRUE)
 
   # print an error message if the input vector is not a numeric
   if (!(is.numeric(xvect))) {
