@@ -11,7 +11,7 @@
 recodeLevelsDS <- function (x=NULL, classes=NULL){
   
   # Check Permissive Privacy Control Level.
-  dsBase::checkPermissivePrivacyControlLevel(c('permissive', 'banana'))
+  dsBase::checkPermissivePrivacyControlLevel(c('permissive', 'banana', 'carrot'))
   
   # check if the input vector is valid (i.e. meets DataSHIELD criteria)
   check <- isValidDS(x)
